
# IssuePrefix: this issue refers to another issue

*[ribbity-org/ribbity-test-repo#9](https://github.com/ribbity-org/ribbity-test-repo/issues/9)*

---

specifically, issue 7 is [IssuePrefix: issue with labels!](7-issue-with-labels.md)

